<?php

/**
 * @package     Joomla.Administrator
 * @subpackage  com_helloworld
 *
 * @copyright   Copyright (C) 2005 - 2016 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access to this file
defined('_JEXEC') or die('Restricted access');

/**
 * HelloWorld Model
 *
 * @since  0.0.1
 */
class OsmaModelModelli extends JModelList {

    public function getItems() {
        $db = JFactory::getDBO();
        $query = $this->costruisciQuery();
        $db->setQuery($query, $this->limitstart, $this->limit);
        $results = $db->loadObjectList();
        return $results;
    }

    public function getTotal() {
        $db = JFactory::getDBO();
        $query = $this->costruisciQuery();
        $db->setQuery($query);
        $db->query();
        $results = $db->getNumRows();
        return $results;
    }

    protected function populateState($ordering = null, $direction = null) {
        $app = JFactory::getApplication('administrator');

        $search = $app->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
        //Omit double (white-)spaces and set state
        $this->setState('filter.search', preg_replace('/\s+/', ' ', $search));
        parent::populateState('ordering', 'ASC');
    }

    public function __construct($config = array()) {
        $config['filter_fields'] = array(
            'ordering',
            'search'
        );
        parent::__construct($config);
        $mainframe = JFactory::getApplication();
        $this->limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
        $this->limitstart = JRequest::getVar('limitstart', 0, '', 'int');
        $this->limitstart = ($this->limit != 0 ? (floor($this->limitstart / $this->limit) * $this->limit) : 0);

        $this->setState('limit', $this->limit);
        $this->setState('limitstart', $this->limitstart);
    }

    public function costruisciQuery() {
        //$filterCompanyName = JRequest::getVar('filterCompanyName');

        $db = JFactory::getDBO();
        $query = $db->getQuery(true);

        $search = $db->escape($this->getState('filter.search'));

        if (empty($search)) {
            $query = "SELECT mo.*,m.marca,t.tipologia FROM #__osma_anagrafica_modelli AS mo
              LEFT JOIN #__osma_anagrafica_marche AS m ON mo.idMarca=m.idMarca
              LEFT JOIN #__osma_anagrafica_tipologie AS t ON mo.idTipologia=t.idTipologia
              WHERE mo.deleted=0 ORDER BY modello ASC";
        } else {
            $search = $db->Quote('%' . $db->escape($search, true) . '%');

            $query = "SELECT mo.*,m.marca,t.tipologia FROM #__osma_anagrafica_modelli AS mo
              LEFT JOIN #__osma_anagrafica_marche AS m ON mo.idMarca=m.idMarca
              LEFT JOIN #__osma_anagrafica_tipologie AS t ON mo.idTipologia=t.idTipologia
              WHERE mo.deleted=0";
            $query .= " AND (mo.modello LIKE " . $search . " OR m.marca LIKE " . $search . " OR t.tipologia LIKE " . $search . ")";
            $query .= " ORDER BY mo.modello ASC";
        }

        return $query;
    }

    function pubblica() {
        $ids = JRequest::getVar("ids");
        $type = JRequest::getVar("type");

        $return = osmaHelper::pubblica($ids, $type);

        return $return;
    }

    function sospendi() {
        $ids = JRequest::getVar("ids");
        $type = JRequest::getVar("type");

        $return = osmaHelper::sospendi($ids, $type);

        return $return;
    }

    function rimuovi() {
        $ids = JRequest::getVar("ids");
        $type = JRequest::getVar("type");

        $return = osmaHelper::rimuovi($ids, $type);

        return $return;
    }

    function salva() {
        $type = JRequest::getVar("type");
        $return = osmaHelper::salvaStrumenti($type);

        echo $return;
    }

    public function getMarche() {
        $db = JFactory::getDBO();
        $query = "SELECT idMarca,marca FROM #__osma_anagrafica_marche WHERE published=1 AND deleted=0 ORDER BY marca ASC";
        $db->setQuery($query);
        $results = $db->loadObjectList();

        echo json_encode($results);
    }

    public function getTipologie() {
        $idMarca = JRequest::getVar('idMarca');
        $db = JFactory::getDBO();
        $query = "SELECT t.idTipologia,t.tipologia FROM #__osma_anagrafica_tipologie AS t
              LEFT JOIN #__osma_xref_marca_tipologie AS xmt ON xmt.idTipologia=t.idTipologia
              WHERE xmt.idMarca=" . $idMarca . " AND t.published=1 AND t.deleted=0 ORDER BY t.tipologia ASC";
        $db->setQuery($query);
        $results = $db->loadObjectList();

        echo json_encode($results);
    }

}
